==> bibledit-web-0.9.tar.gz: bibledit-web-0.9/web/book/books.php <==
<?php
/**
* @package bibledit
*/
/*
** Copyright (©) 2003-2013 Teus Benschop.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**  
*/

// Localization of the names of the books of the Bible.
// The names are gathered from the data below.
// People who wish can translate these.
// The translation can be imported into Bibledit-Web.
// Then localization of the book names works.

gettext ("Front Matter");
gettext ("Genesis");
gettext ("Exodus");
gettext ("Leviticus");
gettext ("Numbers");
gettext ("Deuteronomy");
gettext ("Joshua");
gettext ("Judges");
gettext ("Ruth");
gettext ("1 Samuel");
gettext ("2 Samuel");
gettext ("1 Kings");
gettext ("2 Kings");
gettext ("1 Chronicles");
gettext ("2 Chronicles");
gettext ("Ezra");
gettext ("Nehemiah");
gettext ("Esther");
gettext ("Job");
gettext ("Psalms");
gettext ("Proverbs");
gettext ("Ecclesiastes");
gettext ("Song of Solomon");
gettext ("Isaiah");
gettext ("Jeremiah");
gettext ("Lamentations");
gettext ("Ezekiel");
gettext ("Daniel");
gettext ("Hosea");
gettext ("Joel");
gettext ("Amos");
gettext ("Obadiah");
gettext ("Jonah");
gettext ("Micah");
gettext ("Nahum");
gettext ("Habakkuk");
gettext ("Zephaniah");
gettext ("Haggai");
gettext ("Zechariah");
gettext ("Malachi");
gettext ("Matthew");
gettext ("Mark");
gettext ("Luke");
gettext ("John");
gettext ("Acts");
gettext ("Romans");
gettext ("1 Corinthians");
gettext ("2 Corinthians");
gettext ("Galatians");
gettext ("Ephesians");
gettext ("Philippians");
gettext ("Colossians");
gettext ("1 Thessalonians");
gettext ("2 Thessalonians");
gettext ("1 Timothy");
gettext ("2 Timothy");
gettext ("Titus");
gettext ("Philemon");
gettext ("Hebrews");
gettext ("James");
gettext ("1 Peter");
gettext ("2 Peter");
gettext ("1 John");
gettext ("2 John");
gettext ("3 John");
gettext ("Jude");
gettext ("Revelation");
gettext ("Back Matter");
gettext ("Other Material");

?>

==> bibledit-web-1.2.tar.gz: bibledit-web-1.2/web/book/books.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

// Localization of the names of the books of the Bible.
// The names are gathered from the data below.
// People who wish can translate these.
// The translation can be imported into Bibledit-Web.
// Then localization of the book names works.

gettext ("Front Matter");
gettext ("Genesis");
gettext ("Exodus");
gettext ("Leviticus");
gettext ("Numbers");
gettext ("Deuteronomy");
gettext ("Joshua");
gettext ("Judges");
gettext ("Ruth");
gettext ("1 Samuel");
gettext ("2 Samuel");
gettext ("1 Kings");
gettext ("2 Kings");
gettext ("1 Chronicles");
gettext ("2 Chronicles");
gettext ("Ezra");
gettext ("Nehemiah");
gettext ("Esther");
gettext ("Job");
gettext ("Psalms");
gettext ("Proverbs");
gettext ("Ecclesiastes");
gettext ("Song of Solomon");
gettext ("Isaiah");
gettext ("Jeremiah");
gettext ("Lamentations");
gettext ("Ezekiel");
gettext ("Daniel");
gettext ("Hosea");
gettext ("Joel");
gettext ("Amos");
gettext ("Obadiah");
gettext ("Jonah");
gettext ("Micah");
gettext ("Nahum");
gettext ("Habakkuk");
gettext ("Zephaniah");
gettext ("Haggai");
gettext ("Zechariah");
gettext ("Malachi");
gettext ("Matthew");
gettext ("Mark");
gettext ("Luke");
gettext ("John");
gettext ("Acts");
gettext ("Romans");
gettext ("1 Corinthians");
gettext ("2 Corinthians");
gettext ("Galatians");
gettext ("Ephesians");
gettext ("Philippians");
gettext ("Colossians");
gettext ("1 Thessalonians");
gettext ("2 Thessalonians");
gettext ("1 Timothy");
gettext ("2 Timothy");
gettext ("Titus");
gettext ("Philemon");
gettext ("Hebrews");
gettext ("James");
gettext ("1 Peter");
gettext ("2 Peter");
gettext ("1 John");
gettext ("2 John");
gettext ("3 John");
gettext ("Jude");
gettext ("Revelation");
gettext ("Back Matter");
gettext ("Other Material");

?>
